# -*- encoding: utf-8 -*-
# stub: ssh_sig 0.1.1 ruby lib

Gem::Specification.new do |s|
  s.name = "ssh_sig".freeze
  s.version = "0.1.1"

  s.required_rubygems_version = Gem::Requirement.new(">= 0".freeze) if s.respond_to? :required_rubygems_version=
  s.metadata = { "changelog_uri" => "https://gitlab.com/bwill/ssh_sig/-/blob/main/CHANGELOG.md", "homepage_uri" => "https://gitlab.com/bwill/ssh_sig", "source_code_uri" => "https://gitlab.com/bwill/ssh_sig" } if s.respond_to? :metadata=
  s.require_paths = ["lib".freeze]
  s.authors = ["Brian Williams".freeze]
  s.bindir = "exe".freeze
  s.date = "2021-12-07"
  s.description = "# SshSig - SSH signature verification in pure ruby\n\nSshSig is a Ruby gem which can be used to verify signatures signed created by `ssh-keygen`.\nThis capability was [first added](https://github.com/openssh/openssh-portable/commit/2a9c9f7272c1e8665155118fe6536bebdafb6166) in OpenSSH 8.0\nallows SSH keys to be used for GPG-like signing capabilities, [including signing git commits](https://github.com/git/git/pull/1041).\n\n## Installation\n\nAdd this line to your application's Gemfile:\n\n```ruby\ngem 'ssh_sig'\n```\n\nAnd then execute:\n\n    $ bundle install\n\nOr install it yourself as:\n\n    $ gem install ssh_sig\n\n## Usage\n\nVersion 1 of [the SSH signature format](https://github.com/openssh/openssh-portable/blob/b7ffbb17e37f59249c31f1ff59d6c5d80888f689/PROTOCOL.sshsig)\nsupports `ed25519` and `rsa` keys. It is recommended that you use `ed25519` over `rsa` where possible (`ssh-keygen -t ed25519`).\n\nIn order to verify a signature you need:\n\n1. The public key of the sender\n1. The signature file\n1. The message to be verified.\n\n```ruby\nrequire 'ssh_sig'\n\narmored_pubkey = \"ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAILXPkJPI4TMFWZP4xRBQjNeizUG99KuZCt9G23rX48kz\"\n\nblob = ::SshSig::Blob.from_armor(\n  <<~EOF\n  -----BEGIN SSH SIGNATURE-----\n  U1NIU0lHAAAAAQAAADMAAAALc3NoLWVkMjU1MTkAAAAgtc+Qk8jhMwVZk/jFEFCM16LNQb\n  30q5kK30bbetfjyTMAAAAEZmlsZQAAAAAAAAAGc2hhNTEyAAAAUwAAAAtzc2gtZWQyNTUx\n  OQAAAECJITeYJIlEeydsCTh1DkfdhlDJFBa73ojfWe0MbrIzoJKd9THd9WeQrhygSRGsNG\n  cU/stk3/919nykg67yG2gN\n  -----END SSH SIGNATURE-----\n  EOF\n)\n\nmessage = \"This message was definitely sent by Brian Williams\"\n\nvalid = ::SshSig::Verifier\n  .from_armored_pubkey(armored_pubkey)\n  .verify(blob, message)\n\nif valid\n  puts 'Signature is valid'\nelse\n  puts 'Signature is not valid'\nend\n```\n\nSignatures can be created using `ssh-keygen -Y sign -n file -f ~/.ssh/ed_25519 message.txt`\nand will be outputted in `message.txt.sig`.\n\nPublic keys can be found in a variety of places, including:\n\n- Your `~/.ssh/id_<alg>.pub` file\n- `authorized_keys` files on servers\n- `https://gitlab.com/<username>.keys`\n- `https://github.com/<username>.keys`\n\nThe `SshSig::Verifier#from_gitlab` and `SshSig::Verifier#from_github` methods are provided\nto automatically load public keys from the respective `<username>.keys` urls.\n\n```ruby\nrequire 'ssh_sig'\n\nblob = ::SshSig::Blob.from_armor(\n  <<~EOF\n  -----BEGIN SSH SIGNATURE-----\n  U1NIU0lHAAAAAQAAADMAAAALc3NoLWVkMjU1MTkAAAAgtc+Qk8jhMwVZk/jFEFCM16LNQb\n  30q5kK30bbetfjyTMAAAAEZmlsZQAAAAAAAAAGc2hhNTEyAAAAUwAAAAtzc2gtZWQyNTUx\n  OQAAAECJITeYJIlEeydsCTh1DkfdhlDJFBa73ojfWe0MbrIzoJKd9THd9WeQrhygSRGsNG\n  cU/stk3/919nykg67yG2gN\n  -----END SSH SIGNATURE-----\n  EOF\n)\n\nmessage = 'This message was definitely sent by Brian Williams'\n\nvalid = ::SshSig::Verifier\n  .from_gitlab('bwill')\n  .verify(blob, message)\n\nif valid\n  puts 'Signature is valid'\nelse\n  puts 'Signature is not valid'\nend\n```\n\n## Is it safe to re-purpose SSH keys for signing?\n\nYes. The [SSH signature protocol](https://github.com/openssh/openssh-portable/blob/d575cf44895104e0fcb0629920fb645207218129/PROTOCOL.sshsig)\nis designed to be resistant to cross-protocol attacks, where signatures created for one purpose (i.e. signing a git commit),\nmay be re-used for another purpose (i.e. authenticating to a server). It does this using the magic pre-amble (to differentiate\nbetween messages signed by `ssh-keygen` and messages used for SSH authentication) and namespaces (to differentiate between\nmessages signed by `ssh-keygen` but used for different purposes). This causes identical messages to produce different signatures\nfor each different protocol.\n\n## Development\n\nAfter checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.\n\nTo install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and the created tag, and push the `.gem` file to [rubygems.org](https://rubygems.org).\n\n## Contributing\n\nBug reports and pull requests are welcome on GitHub at https://github.com/[USERNAME]/ssh_sig. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [code of conduct](https://github.com/[USERNAME]/ssh_sig/blob/main/CODE_OF_CONDUCT.md).\n\n## License\n\nThe gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).\n".freeze
  s.email = ["bwilliams@gitlab.com".freeze]
  s.homepage = "https://gitlab.com/bwill/ssh_sig".freeze
  s.licenses = ["MIT".freeze]
  s.required_ruby_version = Gem::Requirement.new(">= 2.7.0".freeze)
  s.rubygems_version = "3.3.7".freeze
  s.summary = "SSH Signatures in Ruby".freeze

  s.installed_by_version = "3.3.7" if s.respond_to? :installed_by_version

  if s.respond_to? :specification_version then
    s.specification_version = 4
  end

  if s.respond_to? :add_runtime_dependency then
    s.add_runtime_dependency(%q<bcrypt_pbkdf>.freeze, ["~> 1.1"])
    s.add_runtime_dependency(%q<ed25519>.freeze, ["~> 1.2"])
    s.add_runtime_dependency(%q<net-ssh>.freeze, [">= 6.3.0.beta1"])
    s.add_runtime_dependency(%q<zeitwerk>.freeze, ["~> 2.4"])
    s.add_development_dependency(%q<gitlab-styles>.freeze, ["~> 6.2.0"])
    s.add_development_dependency(%q<rspec-parameterized>.freeze, ["~> 0.5.0"])
  else
    s.add_dependency(%q<bcrypt_pbkdf>.freeze, ["~> 1.1"])
    s.add_dependency(%q<ed25519>.freeze, ["~> 1.2"])
    s.add_dependency(%q<net-ssh>.freeze, [">= 6.3.0.beta1"])
    s.add_dependency(%q<zeitwerk>.freeze, ["~> 2.4"])
    s.add_dependency(%q<gitlab-styles>.freeze, ["~> 6.2.0"])
    s.add_dependency(%q<rspec-parameterized>.freeze, ["~> 0.5.0"])
  end
end
